#!/bin/bash

#SBATCH --job-name=kmeans_sample_v         # job name
#SBATCH --partition=dev_multiple           # queue for resource allocation
#SBATCH --nodes=4                          # number of nodes to be used
#SBATCH --time=30:00                       # wall-clock time limit
#SBATCH --cpus-per-task=40                 # number of CPUs required per MPI task
#SBATCH --ntasks-per-node=1                # maximum count of tasks per node
#SBATCH --mail-type=ALL                    # Notify user by email when certain event types occur.

export OMP_NUM_THREADS=${SLURM_CPUS_PER_TASK}
export VENVDIR=~/scai-venv                 # Export path to your virtual environment.
export PYDIR=./                            # Export path to directory containing Python script.

# Set up modules.
module purge                               # Unload all currently loaded modules.
module load compiler/gnu/13.3              # Load required modules.
module load mpi/openmpi/4.1
module load devel/cuda/12.4
module load lib/hdf5/1.14.4-gnu-13.3-openmpi-4.1

source ${VENVDIR}/bin/activate # Activate your virtual environment.

mpirun python -u ${PYDIR}/kmeans_sample_parallel_allgatherv.py # Run your Python script.
